aboutsummaryrefslogtreecommitdiffstats
path: root/parameter/EnumParameterType.h
diff options
context:
space:
mode:
authorSebastien Gonzalve <oznog@zarb.org>2014-02-20 22:28:03 +0100
committerDavid Wagner <david.wagner@intel.com>2014-09-11 14:25:02 +0200
commitd9526499d6ab53b7d13d1434f748f6f2161c2e0a (patch)
tree8d2e2db275800821d4bf8873fc16b686bca60b2d /parameter/EnumParameterType.h
parentffbf43b383bb8693741430b02c24dbc9b127f7f7 (diff)
downloadexternal_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.zip
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.gz
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.bz2
Remove using std::XXX from headers
This is a bad practice to have using in headers because it pollutes the namespace of any user of that header.
Diffstat (limited to 'parameter/EnumParameterType.h')
-rw-r--r--parameter/EnumParameterType.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/parameter/EnumParameterType.h b/parameter/EnumParameterType.h
index 5f136a4..681f9b9 100644
--- a/parameter/EnumParameterType.h
+++ b/parameter/EnumParameterType.h
@@ -32,11 +32,12 @@
#include "ParameterType.h"
#include <list>
+#include <string>
class CEnumParameterType : public CParameterType
{
public:
- CEnumParameterType(const string& strName);
+ CEnumParameterType(const std::string& strName);
// From IXmlSink
virtual bool fromXml(const CXmlElement& xmlElement, CXmlSerializingContext& serializingContext);
@@ -46,8 +47,8 @@ public:
/// Conversion
// String
- virtual bool toBlackboard(const string& strValue, uint32_t& uiValue, CParameterAccessContext& parameterAccessContext) const;
- virtual bool fromBlackboard(string& strValue, const uint32_t& uiValue, CParameterAccessContext& parameterAccessContext) const;
+ virtual bool toBlackboard(const std::string& strValue, uint32_t& uiValue, CParameterAccessContext& parameterAccessContext) const;
+ virtual bool fromBlackboard(std::string& strValue, const uint32_t& uiValue, CParameterAccessContext& parameterAccessContext) const;
// Integer
virtual bool toBlackboard(int32_t iUserValue, uint32_t& uiValue, CParameterAccessContext& parameterAccessContext) const;
virtual bool fromBlackboard(int32_t& iUserValue, uint32_t uiValue, CParameterAccessContext& parameterAccessContext) const;
@@ -56,23 +57,23 @@ public:
virtual uint32_t getDefaultValue() const;
// Element properties
- virtual void showProperties(string& strResult) const;
+ virtual void showProperties(std::string& strResult) const;
// CElement
- virtual string getKind() const;
+ virtual std::string getKind() const;
private:
// Returns true if children dynamic creation is to be dealt with
virtual bool childrenAreDynamic() const;
- // Check string is a number
- static bool isNumber(const string& strValue);
+ // Check std::string is a number
+ static bool isNumber(const std::string& strValue);
// Literal - numerical conversions
- bool getLiteral(int32_t iNumerical, string& strLiteral) const;
- bool getNumerical(const string& strLiteral, int& iNumerical) const;
+ bool getLiteral(int32_t iNumerical, std::string& strLiteral) const;
+ bool getNumerical(const std::string& strLiteral, int& iNumerical) const;
// Numerical validity
bool isValid(int iNumerical, CParameterAccessContext& parameterAccessContext) const;
// Range validity
- bool checkValueAgainstRange(const string& strValue, int64_t value, CParameterAccessContext& parameterAccessContext, bool bHexaValue, bool bConversionSucceeded) const;
+ bool checkValueAgainstRange(const std::string& strValue, int64_t value, CParameterAccessContext& parameterAccessContext, bool bHexaValue, bool bConversionSucceeded) const;
};